@@ -8,7 +8,7 @@ use POSIX;
 use Date::Parse;
 
 # ABSTRACT: Fills in string templates from hash of fields
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 our @EXPORT = qw(expand_string missing_values expand_stringi);
@@ -135,19 +135,18 @@ String::Template - Fills in string templates from hash of fields
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
-  use String::Template;
-
-  my %fields = ( num => 2, str => 'this', date => 'Feb 27, 2008' );
-
-  my $template = "...<num%04d>...<str>...<date:%Y/%m/%d>...\n";
-
-  print expand_string($template, \%fields);
-
-  prints: "...0002...this...2008/02/27..."
+ use String::Template;
+ 
+ my %fields = ( num => 2, str => 'this', date => 'Feb 27, 2008' );
+ 
+ my $template = "...<num%04d>...<str>...<date:%Y/%m/%d>...\n";
+ 
+ print expand_string($template, \%fields);
+ #prints: "...0002...this...2008/02/27..."
 
 =head1 DESCRIPTION
 
@@ -218,8 +217,6 @@ Returns undef if there are unexpanded templates left, otherwise true.
 L<String::Format> performs a similar function, with a different
 syntax.
 
-=cut
-
 =head1 AUTHOR
 
 Original author: Brian Duggan
